/*-----------------------------------------------------------------
File "Motor.geo"

This file is the geometrical description used by GMSH to produce
the file "Motor.msh".
-------------------------------------------------------------------*/


/* Definition of parameters for geometrical dimensions */

reje=20e-3;			//radio del eje del motor en [m]
rrot=61.7e-3;			//radio del rotor en [m]
riest=62.5e-3;			//radio interno del estator en [m]
reest=105e-3;			//radio externo del estator en [m]
rinf=120e-3;			//radio del infinito en [m]

ranest=36;			//nmero de ranuras del estator

dientest=4e-3;			//ancho de los dientes del estator en [m]
aislest=0.5e-3;			//espesor de la aislacin del estator en [m]
profest=21.3e-3;		//profundidad de las ranuras del estator en [m]

ranrot=44;			//nmero de ranuras del rotor
apert=1e-3;			//apertura de la superficie del rotor sobre cada barra en [m]
profrot=0.2e-3;			//profundidad del radio de las barras con respecto al radio del rotor
rbar=3e-3;			//radio de las barras del rotor en [m]

betaest=(2*Pi)/ranest;		//ngulo entre ranuras del estator en [rad]
betarot=(2*Pi)/ranrot;		//ngulo entre ranuras del rotor en [rad]

p=2;				//pares de polos
frec=50;			//frecuencia de la red

t=0;				//tiempo para el cual es evaluado la posicin del rotor
slip=1;				//deslizamiento

alfa=2*Pi*frec/p*(1-slip)*t;	//ngulo de giro del rotor (posicin en el tiempo t)


/* Definition of parameters for local mesh dimensions */

Lc=3e-3;
Leje=6*Lc;
Lbarra=0.5*Lc;
Ldevan=1.5*Lc; //0.8
Lest=4*Lc;
Lrot=0.5*Lc;
Linf=10*Lc;
Lairgap=0.2*Lc;

Mesh.Algorithm = 1;
Mesh.Smoothing = 1;
MeshRcmbne=0;



/* Definition of geometrical points */

Point(1)={0,0,0,Leje};

Point(2)={reje,0,0,Leje};		// Eje
Point(3)={0,reje,0,Leje};
Point(4)={-reje,0,0,Leje};
Point(5)={0,-reje,0,Leje};

Point(10)={reest,0,0,Lest};		// Estator externo
Point(11)={0,reest,0,Lest};
Point(12)={-reest,0,0,Lest};
Point(13)={0,-reest,0,Lest};

Point(14)={rinf,0,0,Linf};		// Infinito
Point(15)={0,rinf,0,Linf};
Point(16)={-rinf,0,0,Linf};
Point(17)={0,-rinf,0,Linf};

/* Definition of geometrical lines */

Circle(1)={2,1,3};			// Eje
Circle(2)={3,1,4};
Circle(3)={4,1,5};
Circle(4)={5,1,2};

Circle(9)={10,1,11};			// Estator externo
Circle(10)={11,1,12};
Circle(11)={12,1,13};
Circle(12)={13,1,10};

Circle(13)={14,1,15};			// Infinito
Circle(14)={15,1,16};
Circle(15)={16,1,17};
Circle(16)={17,1,14};

/*   Construccin de las baras del rotor  */


	
supbar=rrot-profrot;			//cuadrante superior de la barra del rotor
cenbar=supbar-rbar;			//centro de la barra del rotor
infbar=supbar-2*rbar;			//cuadrante inferior de la barra del rotor

gamma=Asin(apert/(2*rbar));		
delta=Asin(apert/(2*rrot));

a1=newp; Point(a1)={rrot*Cos(alfa),rrot*Sin(alfa),0,Lairgap};	// Punto inicial contorno del rotor
b1=a1;

For k In {1:ranrot}
	
	/* Definition of parameters for geometrical dimensions */

	cenbeta=(k-0.5)*betarot;	//centro del angulo beta de la ranura 'k'
	
	xrot=rrot*Cos(k*betarot+alfa);	//x: posicin del rotor en el ngulo beta
	yrot=rrot*Sin(k*betarot+alfa);	//y: posicin del rotor en el ngulo beta

	xcen=cenbar*Cos(cenbeta+alfa);	//x: centro de la barra 'k'
	xinf=infbar*Cos(cenbeta+alfa);	//x: cuadrante inferior de la barra 'k'
	xder=xcen+rbar*Sin(cenbeta+alfa);	//x: cuadrante derecho de la barra 'k'
	xizq=xcen-rbar*Sin(cenbeta+alfa);	//x: cuadrante izquierdo de la barra 'k'

	ycen=cenbar*Sin(cenbeta+alfa);	//y: centro de la barra 'k'
	yinf=infbar*Sin(cenbeta+alfa);	//y: cuadrante inferior de la barra 'k'
	yder=ycen-rbar*Cos(cenbeta+alfa);	//y: cuadrante derecho de la barra 'k'
	yizq=ycen+rbar*Cos(cenbeta+alfa);	//y: cuadrante izquierdo de la barra 'k'

	xaizi=cenbar*Cos(cenbeta+alfa)+rbar*Cos(cenbeta+gamma+alfa); //x: apertura izquierda interior del rotor 'k'
	xadei=cenbar*Cos(cenbeta+alfa)+rbar*Cos(cenbeta-gamma+alfa); //x: apertura derecha interior del rotor 'k'

	yaizi=cenbar*Sin(cenbeta+alfa)+rbar*Sin(cenbeta+gamma+alfa); //y: apertura izquierda interior del rotor 'k'
	yadei=cenbar*Sin(cenbeta+alfa)+rbar*Sin(cenbeta-gamma+alfa); //y: apertura derecha interior del rotor 'k'

	xaize=rrot*Cos(cenbeta+delta+alfa); 			//x: apertura izquierda exterior del rotor 'k'
	xadee=rrot*Cos(cenbeta-delta+alfa); 			//x: apertura derecha exterior del rotor 'k'

	yaize=rrot*Sin(cenbeta+delta+alfa); 			//y: apertura izquierda exterior del rotor 'k'
	yadee=rrot*Sin(cenbeta-delta+alfa); 			//y: apertura derecha exterior del rotor 'k'

	/* Definition of geometrical points */

	p1=newp; Point(p1)={xcen,ycen,0,Lbarra};	// Contorno de la barra 'k'
	p2=newp; Point(p2)={xadee,yadee,0,Lairgap};
	p3=newp; Point(p3)={xadei,yadei,0,Lairgap};
	p4=newp; Point(p4)={xder,yder,0,Lbarra};
	p5=newp; Point(p5)={xinf,yinf,0,Lbarra};
	p6=newp; Point(p6)={xizq,yizq,0,Lbarra};
	p7=newp; Point(p7)={xaizi,yaizi,0,Lairgap};
	p8=newp; Point(p8)={xaize,yaize,0,Lairgap};

	/* Definition of geometrical lines */

	p10=newl; Line(p10)={p2,p3};			// Contorno de la ranura del rotor
	p11=newl; Circle(p11)={p3,p1,p4};
	p12=newl; Circle(p12)={p4,p1,p5};
	p13=newl; Circle(p13)={p5,p1,p6};
	p14=newl; Circle(p14)={p6,p1,p7};
	p15=newl; Line(p15)={p7,p8};

	p16=newl; Circle(p16)={p3,p1,p7};

	p20=news; Line Loop(p20)={p11,p12,p13,p14,-p16};  // Superficie de cada barra
	k1=k;	Plane Surface(k1)={p20};
	
	If ( k==1 )
		Color Red { Surface{k1}; }	
	EndIf

	If ( k!=1 )
		Color SpringGreen{ Surface{k1}; }	
	EndIf

	If (MeshRcmbne > 0 )
		Recombine Surface {k1};
	EndIf

	barrloop[k-1]=p20;				// Line Loop de cada barra	
	barrsurf[k-1]=k1;				// Plane Surface de todas las barras


	If ( k!=ranrot )
		 c1=newp; Point(c1)={xrot,yrot,0,Lairgap};
	EndIf

	If ( k==ranrot )	
		 c1=a1;
	EndIf

	p30=newl; Circle(p30)={b1,1,p2};		// segmento del radio externo del rotor
	p32=newl; Circle(p32)={p8,1,c1};	

	contintgap[(5*k-1)-4]=p30;			// Contorno interno del entrehierro
	contintgap[(5*k-1)-3]=p10;
	contintgap[(5*k-1)-2]=p16;
	contintgap[(5*k-1)-1]=p15;
	contintgap[(5*k-1)-0]=p32;

	controt[(8*k-1)-7]=p30;				// Contorno del rotor sobre cada barra
	controt[(8*k-1)-6]=p10;
	controt[(8*k-1)-5]=p11;
	controt[(8*k-1)-4]=p12;
	controt[(8*k-1)-3]=p13;
	controt[(8*k-1)-2]=p14;
	controt[(8*k-1)-1]=p15;
	controt[(8*k-1)-0]=p32;
	
	b1=c1;		

EndFor


/* Construccin del contorno interno del estator, incluyendo devanados y aislaciones */

a2=newp; Point(a2)={riest,0,0,Lairgap};	// Punto inicial radio interno estator
b2=a2;

For m In {1:ranest}

	/* Definition of parameters for geometrical dimensions */

	xest=riest*Cos(m*betaest);		//x: posicin del estator en el ngulo beta
	yest=riest*Sin(m*betaest);		//y: posicin del estator en el ngulo beta
		
	x1=riest*Cos((m-2/3)*betaest);		//x: punto der de la apertura de la ranura
	y1=riest*Sin((m-2/3)*betaest);		//y: punto der de la apertura de la ranura
	x2=riest*Cos((m-1/3)*betaest);		//x: punto izq de la apertura de la ranura
	y2=riest*Sin((m-1/3)*betaest);		//y: punto izq de la apertura de la ranura

	x3=(riest+1e-3)*Cos((m-2/3)*betaest);	//x: punto interno der de la apertura de la ranura
	y3=(riest+1e-3)*Sin((m-2/3)*betaest);	//y: punto interno der de la apertura de la ranura
	x4=(riest+1e-3)*Cos((m-1/3)*betaest);	//x: punto interno izq de la apertura de la ranura
	y4=(riest+1e-3)*Sin((m-1/3)*betaest);	//y: punto interno izq de la apertura de la ranura
	
	x5=(riest+1e-3)*Cos((m-1)*betaest)-(dientest/2)*Sin((m-1)*betaest);
	y5=(riest+1e-3)*Sin((m-1)*betaest)+(dientest/2)*Cos((m-1)*betaest);
	x6=(riest+1e-3)*Cos(m*betaest)+(dientest/2)*Sin(m*betaest);
	y6=(riest+1e-3)*Sin(m*betaest)-(dientest/2)*Cos(m*betaest);

	x7=x5+profest*Cos((m-1)*betaest);	//y: punto der fondo de la ranura
	y7=y5+profest*Sin((m-1)*betaest);	//y: punto der fondo de la ranura
	x8=x6+profest*Cos(m*betaest);		//y: punto izq fondo de la ranura
	y8=y6+profest*Sin(m*betaest);		//y: punto izq fondo de la ranura
	
	x9=x5+aislest*(Cos((m-1)*betaest)-Sin((m-1)*betaest));	// Conductores del estator 
	y9=y5+aislest*(Cos((m-1)*betaest)+Sin((m-1)*betaest));
	x10=x6+aislest*(Cos(m*betaest)+Sin(m*betaest));
	y10=y6+aislest*(Sin(m*betaest)-Cos(m*betaest));
	x11=x9+(profest-2*aislest)*Cos((m-1)*betaest);
	y11=y9+(profest-2*aislest)*Sin((m-1)*betaest);
	x12=x10+(profest-2*aislest)*Cos(m*betaest);
	y12=y10+(profest-2*aislest)*Sin(m*betaest);

	x13=x9+(profest-3*aislest)/2*Cos((m-1)*betaest);
	y13=y9+(profest-3*aislest)/2*Sin((m-1)*betaest);
	x14=x10+(profest-3*aislest)/2*Cos(m*betaest);
	y14=y10+(profest-3*aislest)/2*Sin(m*betaest);
	x15=x11-(profest-3*aislest)/2*Cos((m-1)*betaest);
	y15=y11-(profest-3*aislest)/2*Sin((m-1)*betaest);
	x16=x12-(profest-3*aislest)/2*Cos(m*betaest);
	y16=y12-(profest-3*aislest)/2*Sin(m*betaest);

	/* Definition of geometrical points */

	q1=newp;  Point(q1)={x1,y1,0,Lairgap};			// Conductores del estator
	q2=newp;  Point(q2)={x3,y3,0,Ldevan};
	q3=newp;  Point(q3)={x5,y5,0,Ldevan};
	q4=newp;  Point(q4)={x7,y7,0,Ldevan};
	q5=newp;  Point(q5)={x8,y8,0,Ldevan};
	q6=newp;  Point(q6)={x6,y6,0,Ldevan};
	q7=newp;  Point(q7)={x4,y4,0,Ldevan};
	q8=newp;  Point(q8)={x2,y2,0,Lairgap};
	
	q9=newp;  Point(q9)={x9,y9,0,Ldevan};			// Contorno de devanado superior
	q10=newp; Point(q10)={x13,y13,0,Ldevan};
	q11=newp; Point(q11)={x14,y14,0,Ldevan};
	q12=newp; Point(q12)={x10,y10,0,Ldevan};

	q13=newp; Point(q13)={x15,y15,0,Ldevan};		// Contorno de devanado inferior
	q14=newp; Point(q14)={x11,y11,0,Ldevan};
	q15=newp; Point(q15)={x12,y12,0,Ldevan};
	q16=newp; Point(q16)={x16,y16,0,Ldevan};
	
	/* Definition of geometrical lines */

	q17=newl; Line(q17)={q1,q2};				// Contorno de ranura
	q18=newl; Line(q18)={q2,q3};
	q19=newl; Line(q19)={q3,q4};
	q20=newl; Line(q20)={q4,q5};
	q21=newl; Line(q21)={q5,q6};
	q22=newl; Line(q22)={q6,q7};
	q23=newl; Line(q23)={q7,q8};
	
	q24=newl; Line(q24)={q9,q10};				// Contorno de devanado superior
	q25=newl; Line(q25)={q10,q11};
	q26=newl; Line(q26)={q11,q12};
	q27=newl; Line(q27)={q12,q9};
	
	q28=newl; Line(q28)={q13,q14};				// Contorno de devanado inferior
	q29=newl; Line(q29)={q14,q15};
	q30=newl; Line(q30)={q15,q16};
	q31=newl; Line(q31)={q16,q13};

	
	q32=news; Line Loop(q32)={q24,q25,q26,q27};		// Contorno devanado superior
	m1=100+m; Plane Surface(m1)={q32};

	q34=news; Line Loop(q34)={q28,q29,q30,q31};		// Contorno devanado inferior
	m2=200+m; Plane Surface(m2)={q34};
	
	devansurf[(2*m-1)-1]=m1;				// Plane Surface de cada devanado
	devansurf[(2*m-1)-0]=m2;

	If (MeshRcmbne > 0 )
		Recombine Surface {m1,m2};
	EndIf


	If ( m!=ranest )
		 c2=newp; Point(c2)={xest,yest,0,Lairgap};
	EndIf

	If ( m==ranest )	
		 c2=a2;
	EndIf

	q36=newl; Circle(q36)={b2,1,q1};			// segmento del radio interno del estator
	q37=newl; Circle(q37)={q1,1,q8};	
	q38=newl; Circle(q38)={q8,1,c2};	

	b2=c2;

	radintest[(3*m-1)-2]=q36;				// segmento del radio interno del estator 
	radintest[(3*m-1)-1]=q37;		
	radintest[(3*m-1)-0]=q38;

	q39=news; Line Loop(q39)={q17,q18,q19,q20,q21,q22,q23,-q37};	// Contorno de ranura
	m3=300+m; Plane Surface(m3)={q39,q32,q34};		// Superficie aislacin del estator

	Color Blue { Surface{m3}; }

	If (MeshRcmbne > 0 )
		Recombine Surface {m3};
	EndIf

	aislacion[m-1]=m3;					// Plane Surface de cada aislacin

	contintest[(9*m-1)-8]=q36;				// Contorno del estator sobre cada ranura
	contintest[(9*m-1)-7]=q17;
	contintest[(9*m-1)-6]=q18;
	contintest[(9*m-1)-5]=q19;
	contintest[(9*m-1)-4]=q20;
	contintest[(9*m-1)-3]=q21;
	contintest[(9*m-1)-2]=q22;
	contintest[(9*m-1)-1]=q23;
	contintest[(9*m-1)-0]=q38;

EndFor


/* Definition of geometrical surfaces */

Line Loop(500) = {1:4};			// Contorno del eje
Plane Surface(501) = {500};		// Superficie del eje	
Color Grey25 { Surface{501}; }

Line Loop(502)={controt[]};		// Contorno del rotor
Plane Surface(503)={502,500};		// Superficie ncleo del rotor
Color Grey45 { Surface{503}; }

Line Loop(504)={radintest[]}; 		// Contorno del radio interno del estator
Line Loop(505)={contintgap[]};
Plane Surface(506)={504,505};		// Superficie entrehierro
Color Red { Surface{506}; }

Line Loop(510)={contintest[]};		// Contorno interno del estator (ranuras)
Line Loop(512)={9:12};			// Contorno externo del estator
Plane Surface(513)={512,510};		// Superficie ncleo del estator
Color Grey45 { Surface{513}; }

Line Loop(516) = {13:16};		// Contorno de externo del infinito
Plane Surface(517) = {516,512};		// Superficie del infinito
Color Brown { Surface{517}; }

Physical Line(2)={13:16};		// Circunferencia del infinito (Dirichlet)

Physical Surface(3)={501};		// Superficie del eje
Physical Surface(4)={503};		// Superficie del ncleo del rotor
Physical Surface(5)={506};		// Superficie del entrehierro
Physical Surface(6)={513};		// Superficie del ncleo del estator
Physical Surface(7)={517};		// Superficie del infinito
Physical Surface(8)={aislacion[]};	// Superficie de todas las aislaciones del estator

Physical Surface(10)={201:203,219:221,102:104,120:122};		// Superficies de la fase a entrando
Physical Surface(11)={204:206,222:224,105:107,123:125};		// Superficies de la fase c saliendo
Physical Surface(12)={207:209,225:227,108:110,126:128};		// Superficies de la fase b entrando
Physical Surface(13)={210:212,228:230,111:113,129:131};		// Superficies de la fase a saliendo
Physical Surface(14)={213:215,231:233,114:116,132:134};		// Superficies de la fase c entrando
Physical Surface(15)={216:218,234:236,117:119,135,136,101};	// Superficies de la fase b saliendo

Color Red	{ Surface{201:203,219:221,102:104,120:122}; }
Color Green	{ Surface{204:206,222:224,105:107,123:125}; }
Color Yellow	{ Surface{207:209,225:227,108:110,126:128}; }
Color Magenta	{ Surface{210:212,228:230,111:113,129:131}; }
Color Cyan	{ Surface{213:215,231:233,114:116,132:134}; }
Color Orange	{ Surface{216:218,234:236,117:119,135,136,101}; }

If (MeshRcmbne > 0 )
	Recombine Surface {501,503,506,513,516};
EndIf 

For n In {1:ranrot}
	Physical Surface(19+n)={barrsurf[n-1]};	// Superficie de cada barras del rotor
EndFor