/*-----------------------------------------------------------------
File "Motor.pro"

This file defines the problem dependent data structures for
an Magnetodynamic 2D Asincronous Motor problem.

-------------------------------------------------------------------*/

/* Definition of group */

Group {
	Cero 	 = Region[2];  
	Eje 	 = Region[3];
	NuclRot	 = Region[4];
	Gap	 = Region[5];
	NuclEst  = Region[6];
	Aire 	 = Region[7];
	Aislacion= Region[8];
	
	FaseAin  = Region[10];
	FaseCout = Region[11];
	FaseBin  = Region[12];
	FaseAout = Region[13];
	FaseCin  = Region[14];
	FaseBout = Region[15];

	Fases	 = Region[{FaseAin,FaseCout,FaseBin,FaseAout,FaseCin,FaseBout}];

	Barra01  = Region[20];	Barra16  = Region[35];	Barra31  = Region[50];
	Barra02  = Region[21];	Barra17  = Region[36];	Barra32  = Region[51];
	Barra03  = Region[22];	Barra18  = Region[37];	Barra33  = Region[52];
	Barra04  = Region[23];	Barra19  = Region[38];	Barra34  = Region[53];
	Barra05  = Region[24];	Barra20  = Region[39];	Barra35  = Region[54];
	Barra06  = Region[25];	Barra21  = Region[40];	Barra36  = Region[55];
	Barra07  = Region[26];	Barra22  = Region[41];	Barra37  = Region[56];
	Barra08  = Region[27];	Barra23  = Region[42];	Barra38  = Region[57];
	Barra09  = Region[28];	Barra24  = Region[43];	Barra39  = Region[58];
	Barra10  = Region[29];	Barra25  = Region[44];	Barra40  = Region[59];
	Barra11  = Region[30];	Barra26  = Region[45];	Barra41  = Region[60];
	Barra12  = Region[31];	Barra27  = Region[46];	Barra42  = Region[61];
	Barra13  = Region[32];	Barra28  = Region[47];	Barra43  = Region[62];
	Barra14  = Region[33];	Barra29  = Region[48];	Barra44  = Region[63];
	Barra15  = Region[34];	Barra30  = Region[49];	

	Barras	 = Region[{Barra01,Barra02,Barra03,Barra04,Barra05,Barra06,Barra07,
				Barra08,Barra09,Barra10,Barra11,Barra12,Barra13,Barra14,
				Barra15,Barra16,Barra17,Barra18,Barra19,Barra20,Barra21,
				Barra22,Barra23,Barra24,Barra25,Barra26,Barra27,Barra28,
				Barra29,Barra30,Barra31,Barra32,Barra33,Barra34,Barra35,
				Barra36,Barra37,Barra38,Barra39,Barra40,Barra41,Barra42,
				Barra43,Barra44}];

	Magnetico   = Region[{Eje,NuclRot,NuclEst}];
	ConducEst   = Region[{Fases}];
	ConducRot   = Region[{Barras}];
	Conductor   = Region[{ConducEst,ConducRot}];
	NoCondNoMag = Region[{Aire,Gap,Aislacion}];
	Rotor	    = Region[{Eje,NuclRot,Barras}];
	Estator	    = Region[{Aislacion,NuclEst,Fases}];
	Todo 	    = Region[{Magnetico,Conductor,NoCondNoMag}];	
}


Function {
	NbIso=60;
	NbHTT=44;

	mu0=Pi*4e-7;
	murnucl=5000;
	mureje=1000;

	nu[Eje]=1/(mureje*mu0);
	nu[#{NuclRot,NuclEst}]=1/(murnucl*mu0);
	nu[#{Conductor,NoCondNoMag}]=1/mu0;
	
	sigma[Conductor]=5.8e7;
	sigma[Magnetico]=2.5e2;
	
	SecDev[]=SurfaceArea[];  

	Nesp=60;
	Inom=6;		// Valor mximo
	Frec=50;
	wt=2*Pi*Frec; 
	phi=2*Pi/3;
	phaseA=0;
	phaseB=phaseA-phi;
	phaseC=phaseA+phi;

	Corr_FaseAi[FaseAin] =-Nesp*Inom*F_Cos_wt_p[]{wt,phaseA};
	Corr_FaseCo[FaseCout]= Nesp*Inom*F_Cos_wt_p[]{wt,phaseC};
	Corr_FaseBi[FaseBin] =-Nesp*Inom*F_Cos_wt_p[]{wt,phaseB};
	Corr_FaseAo[FaseAout]= Nesp*Inom*F_Cos_wt_p[]{wt,phaseA};
	Corr_FaseCi[FaseCin] =-Nesp*Inom*F_Cos_wt_p[]{wt,phaseC};
	Corr_FaseBo[FaseBout]= Nesp*Inom*F_Cos_wt_p[]{wt,phaseB};

	slip=0;

	parpolo=2;
	
	wrot=(1-slip)*wt/parpolo;
	velocity[]=Vector[-Y[]*wrot,X[]*wrot,0];

}


Constraint {
	{ Name Ao; Type Assign;
		Case { 
			{ Region Cero; Value 0; }
		}
	}

	{ Name Uo; Type Assign;
		Case { 
			{ Region ConducRot; Value 0; }
		}
	}

	{ Name Jo; Type Assign;
		Case {
			{ Region FaseAin;  Value Corr_FaseAi[]/SecDev[]; }
			{ Region FaseCout; Value Corr_FaseCo[]/SecDev[]; }
			{ Region FaseBin;  Value Corr_FaseBi[]/SecDev[]; }
			{ Region FaseAout; Value Corr_FaseAo[]/SecDev[]; }
			{ Region FaseCin;  Value Corr_FaseCi[]/SecDev[]; }
			{ Region FaseBout; Value Corr_FaseBo[]/SecDev[]; }
		}
	}
}

//-----------------------------------------------------------------

Include "Jacobian.pro"
Include "Integration.pro"
Include "Formulation.pro"

//-----------------------------------------------------------------


PostOperation {
	{ Name A; NameOfPostProcessing Magnet;
		Operation {
			Print[ a,	OnElementsOf Todo, File "A.pos" ];
			Print[ az,	OnElementsOf Todo, File "Az.pos" ];
		}
	}
	{ Name BH; NameOfPostProcessing Magnet;
		Operation {
			Print[ b,	OnElementsOf Todo, File "B.pos" ];
			Print[ h,	OnElementsOf Todo, File "H.pos" ];
		}
	}
	{ Name Flujo; NameOfPostProcessing Magnet;
		Operation {
			Print[ PVM,	OnElementsOf Todo, File "Flujo.pos", 
					HarmonicToTime NbHTT ];
		}
	}
	{ Name J; NameOfPostProcessing Magnet;
		Operation {
			Print[ ja,    	OnElementsOf ConducRot, File "Ja.pos", 
					HarmonicToTime NbHTT ];
			Print[ jv,    	OnElementsOf ConducRot, File "Jv.pos", 
					HarmonicToTime NbHTT ];
			Print[ jr,   	OnElementsOf ConducRot, File "Jr.pos", 
					HarmonicToTime NbHTT ];

			Print[ js,  	OnElementsOf ConducEst, File "Js.pos",
					HarmonicToTime NbHTT ];

		}
	}
	{ Name GAP; NameOfPostProcessing Magnet;
		Operation {
			Print[ agap,	OnElementsOf Gap, File "Agap.pos" ];
			Print[ bgap,	OnElementsOf Gap, File "Bgap.pos" ];
			Print[ fluxgap,	OnElementsOf Gap, File "Fluxgap.pos", 
					HarmonicToTime NbHTT ];
		}
	}
	{ Name IBarr; NameOfPostProcessing Magnet;
		Operation {
			Print[ Ir,    	OnRegion Barra01, File  "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra02, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra03, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra04, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra05, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra06, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra07, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra08, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra09, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra10, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra11, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra12, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra13, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra14, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra15, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra16, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra17, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra18, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra19, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra20, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra21, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra22, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra23, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra24, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra25, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra26, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra27, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra28, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra29, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra30, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra31, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra32, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra33, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra34, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra35, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra36, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra37, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra38, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra39, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra40, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra41, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra42, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra43, File> "Ir.txt", Format Table ];
			Print[ Ir,    	OnRegion Barra44, File> "Ir.txt", Format Table ];
		}
	}
}